@@ -10,7 +10,7 @@ import tensorflow as tf
 
 class Learner:
     """
-    Soft Actor-Critic
+    Learner (based on Soft Actor-Critic)
     =================
 
     Paper: https://arxiv.org/pdf/1812.05905.pdf
@@ -18,8 +18,6 @@ class Learner:
     Attributes:
         env: the instance of environment object
         max_steps (int): maximum number of interactions do in environment
-        env_steps (int): maximum number of steps in each rollout
-        gradient_steps (int): number of update steps after each rollout
         learning_starts (int): number of interactions before using policy network
         buffer_capacity (int): the capacity of experiences replay buffer
         batch_size (int): size of mini-batch used for training
@@ -31,6 +29,8 @@ class Learner:
         model_a_path (str): path to the actor's model
         model_c1_path (str): path to the critic_1's model
         model_c2_path (str): path to the critic_2's model
+        save_path (str): path to the models for saving
+        db_path (str): path to the database
         logging_wandb (bool): logging by WanDB
     """
 
@@ -39,7 +39,6 @@ class Learner:
         # ---
         env,
         max_steps: int,
-        gradient_steps: int = 64,
         learning_starts: int = 10000,
         # ---
         buffer_capacity: int = 1000000,
@@ -62,18 +61,12 @@ class Learner:
     ):
         self._env = env
         self._max_steps = max_steps
-        self._gradient_steps = gradient_steps
+        self._learning_starts = learning_starts
         self._gamma = tf.constant(gamma)
         self._tau = tf.constant(tau)
         self._logging_wandb = logging_wandb
         self._save_path = save_path
 
-        # logging metrics
-        self._loss_a = tf.keras.metrics.Mean()
-        self._loss_c1 = tf.keras.metrics.Mean()
-        self._loss_c2 = tf.keras.metrics.Mean()
-        self._loss_alpha = tf.keras.metrics.Mean()
-
         # init param 'alpha' - Lagrangian constraint
         self._log_alpha = tf.Variable(0.0, trainable=True, name="log_alpha")
         self._alpha = tf.Variable(0.0, trainable=False, name="alpha")
@@ -194,7 +187,6 @@ class Learner:
 
             # Settings
             wandb.config.max_steps = max_steps
-            wandb.config.gradient_steps = gradient_steps
             wandb.config.learning_starts = learning_starts
             wandb.config.buffer_capacity = buffer_capacity
             wandb.config.batch_size = batch_size
@@ -312,64 +304,63 @@ class Learner:
         return alpha_loss
 
     @tf.function
-    def _update(self):
-        for sample in self._dataset.take(self._gradient_steps):
-            # re-new noise matrix every update of 'log_std' params
-            self._actor.reset_noise()
+    def _train_on_batch(self, batch):
+        # re-new noise matrix every update of 'log_std' params
+        self._actor.reset_noise()
 
-            # Alpha param update
-            self._loss_alpha.update_state(self._update_alpha(sample))
+        # Alpha param update
+        loss_alpha = self._update_alpha(batch)
 
-            l_c1, l_c2 = self._update_critic(sample)
-            self._loss_c1.update_state(l_c1)
-            self._loss_c2.update_state(l_c2)
+        # Critic models update
+        loss_c1, loss_c2 = self._update_critic(batch)
 
-            # Actor model update
-            self._loss_a.update_state(self._update_actor(sample))
+        # Actor model update
+        loss_a = self._update_actor(batch)
 
-            # -------------------- soft update target networks -------------------- #
-            self._update_target(self._critic_1, self._critic_targ_1, tau=self._tau)
-            self._update_target(self._critic_2, self._critic_targ_2, tau=self._tau)
+        # -------------------- soft update target networks -------------------- #
+        self._update_target(self._critic_1, self._critic_targ_1, tau=self._tau)
+        self._update_target(self._critic_2, self._critic_targ_2, tau=self._tau)
 
-            # store new actor's params
-            self._push_variables()
+        # store new actor's params
+        self._push_variables()
+
+        return loss_alpha, loss_c1, loss_c2, loss_a
 
     def run(self):
-        for self._total_steps in range(self._max_steps):
-            # update models
-            self._update()
-            self._logging_models()
+        self._total_steps = self._learning_starts
 
-    def _logging_models(self):
-        print("=============================================")
-        print(f"Step: {self._total_steps}")
-        print(f"Actor's loss: {self._loss_a.result()}")
-        print(f"Critic 1's loss: {self._loss_c1.result()}")
-        print(f"Critic 2's loss: {self._loss_c2.result()}")
-        print("=============================================")
-        print(
-            f"Training ... {math.floor(self._total_steps * 100.0 / self._max_steps)} %"
-        )
+        for sample in self._dataset.take(self._max_steps):
+            # update models
+            loss_alpha, loss_c1, loss_c2, loss_a = self._train_on_batch(sample)
+            self._logging_models(loss_alpha, loss_c1, loss_c2, loss_a)
+
+            # update variables
+            self._total_steps += 1
+
+    def _logging_models(self, loss_alpha, loss_c1, loss_c2, loss_a):
+        # logging frequency
+        if self._total_steps % 64 == 0:
+            print("=============================================")
+            print(f"Step: {self._total_steps}")
+            print(f"Actor's loss: {loss_a}")
+            print(f"Critic 1's loss: {loss_c1}")
+            print(f"Critic 2's loss: {loss_c2}")
+            print("=============================================")
+            print(
+                f"Training ... {math.floor(self._total_steps * 100.0 / self._max_steps)} %"  # noqa
+            )
         if self._logging_wandb:
             # logging of epoch's mean loss
             wandb.log(
                 {
-                    "loss_a": self._loss_a.result(),
-                    "loss_c1": self._loss_c1.result(),
-                    "loss_c2": self._loss_c2.result(),
-                    "loss_alpha": self._loss_alpha.result(),
+                    "loss_a": loss_a,
+                    "loss_c1": loss_c1,
+                    "loss_c2": loss_c2,
+                    "loss_alpha": loss_alpha,
                     "alpha": self._alpha,
                 },
                 step=self._total_steps,
             )
-        self._clear_metrics()  # clear stored metrics of losses
-
-    def _clear_metrics(self):
-        # reset logger
-        self._loss_a.reset_states()
-        self._loss_c1.reset_states()
-        self._loss_c2.reset_states()
-        self._loss_alpha.reset_states()
 
     def save(self):
         if self._save_path is not None:
